/**
 * Copyright (c) 2009 Symantec
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the 'Software'), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
 
package com.symantec.premiumServices.asyncThreading.events {
	
	import com.symantec.premiumServices.asyncThreading.interfaces.IAsyncThreadMessage;
	import com.symantec.premiumServices.asyncThreading.interfaces.IAsyncThreadResponder;
	
	import flash.events.Event; 

	/**
	 * Dispatched by the AbstractAsyncThread class.
	 *  
	 * @author ben rimbey -> ben_rimbey@symantec.com, ben.rimbey@gmail.com 
	 * 
	 */
	public class AsyncThreadEvent extends Event {
		
		/**
		 * constant event type. dispatched when the thread is put to sleep.
		 */
		public static const SLEEP:String = "sleep";
		/**
		 * constant event type. dispatched when the thread is woken up.
		 */
		public static const WAKE:String = "wake";
		/**
		 * constant event type. dispatched when the thread is started.
		 */
		public static const START:String = "start";
		/**
		 * constant event type. dispatched when the thread is killed.
		 */
		public static const KILL:String = "kill";
		/**
		 * constant event type. dispatched when the thread has received a message from the AsyncThreading framework.
		 */
		public static const MESSAGE_RECEIVED:String = "messageReceived";
		
		/**
		 * the instance impementing IAsyncThreadResponder which dispatched this event.
		 * 
		 * @see IAsyncThreadResponder
		 */
		public var thread:IAsyncThreadResponder;
		/**
		 * the message that was assigned to this event, if applicable.
		 * 
		 * @see IAsyncThreadMessage 
		 */
		public var message:IAsyncThreadMessage;
		
		/**
		 * Constructor; an IAsyncThreadResponder instance must be passed in.
		 * 
		 * @param type
		 * @param thread
		 * 
		 */
		public function AsyncThreadEvent(type:String, thread:IAsyncThreadResponder) {
			super(type, true, false);
			this.thread = thread;
		}
		
	}
}