/**
 * Copyright (c) 2009 Symantec
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the 'Software'), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
 
 package com.symantec.premiumServices.asyncThreading.interfaces {
	
	/**
	 * interface used to define the basic construct needed for a message being passed around the system.
	 * 
	 * @author ben rimbey -> ben_rimbey@symantec.com, ben.rimbey@gmail.com 
	 * 
	 */
	public interface IAsyncThreadMessage {
		
		/**
		 * retrieves the name of the message. internally, this is used to set which 'mailbox' the 
		 * message is delivered to.
		 * 
		 * @return String 
		 * 
		 */
		function get name():String;
		
		/**
		 * sets the name of the message. internally, this is used to set which 'mailbox' the 
		 * message is delivered to.
		 * 
		 * @param val
		 * 
		 */
		function set name(val:String):void;
		
		/**
		 * retrieves the data that is attached to the message. we leave it as an untyped object so that any 
		 * data can be passed around.
		 * 
		 * @return Object 
		 * 
		 */
		function get body():Object;
		
		/**
		 * sets the value of the data that is attached to the message.
		 *  
		 * @param val
		 * 
		 */
		function set body(val:Object):void;
		
	}
}