/**
 * Copyright (c) 2009 Symantec
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the 'Software'), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
 
package com.symantec.premiumServices.asyncThreading.interfaces {
	
	/**
	 * interface used to define the signature of instances extending AbstractAsyncThread. 
	 * 
	 * <p>PLEASE NOTE: the AbstractAsyncThread base class absolutely MUST be extended by a class 
	 * either implementing this interface or implementing an interface extended from this interface. 
	 * failure to do so will yield a runtime exception.</p>
	 * 
	 * @author ben rimbey -> ben_rimbey@symantec.com, ben.rimbey@gmail.com 
	 * 
	 */
	public interface IAsyncThreadResponder {
		
		/**
		 * this is the execution entry point for your thread object. put the code that you want executed 
		 * on every thread execution within this method.
		 * 
		 * <p>it is invoked by the AbstractAsyncThread base class.</p> 
		 * 
		 * @see AbstractAsyncThread
		 */
		function execute():void;
		
	}
}