/**
 * Copyright (c) 2009 Symantec
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the 'Software'), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
 
 package com.symantec.premiumServices.asyncThreading.interfaces {
	
	/**
	 * interface used to define method signatures for scalable thread objects.
	 * 
	 * @author ben rimbey -> ben_rimbey@symantec.com, ben.rimbey@gmail.com 
	 * 
	 */
	public interface IAsyncThreadScalableResponder extends IAsyncThreadResponder {
		
		/**
		 * the code that will increase the amount of work that your thread does on every 
		 * execution cycle should be placed here.
		 * 
		 * <p>this method is invoked by the <code>AsyncThreadHandler<code> instance maintained 
		 * by the <code>AsyncThreadingManager</code> singleton.</p>
		 * 
		 * @see AsyncThreadingManager
		 */
		function increaseWorkLoad():void;
		
		/**
		 * the code that will decrease the amount of work that your thread does on every 
		 * execution cycle should be placed here.
		 * 
		 * <p>this method is invoked by the <code>AsyncThreadHandler<code> instance maintained 
		 * by the <code>AsyncThreadingManager</code> singleton.</p>
		 * 
		 * @see AsyncThreadingManager
		 */
		function decreaseWorkLoad():void;
		
	}
}