/**
 * Copyright (c) 2009 Symantec
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the 'Software'), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.symantec.premiumServices.asyncThreading.interfaces {
	
	import flash.display.DisplayObject;
	
	/**
	 * interface used to define method signatures for objects that monitor the framerates for 
	 * DisplayObjects.
	 * 
	 * @author ben rimbey -> ben_rimbey@symantec.com, ben.rimbey@gmail.com 
	 * 
	 */
	public interface IFPSObserver {
	
		/**
		 * tells the class implementing this interface to begin monitoring framerate.
		 *  
		 * @param uiReference
		 * @param enterFrameCallBack
		 * 
		 */
		function start(uiReference:DisplayObject, enterFrameCallBack:Function=null):void;
		/**
		 * attempts to kill the class implementing this interface. if it can not be done, we 
		 * return false.
		 *  
		 * @return Boolean
		 * 
		 */
		function kill():Boolean;
		
		/**
		 * returns the current averaged fps of the DisplayObject being observed.
		 *  
		 * @return int 
		 * 
		 */		
		function get fps():int;
		/**
		 * returns the last raw (unaveraged) fps reading of the DisplayObject being observed.
		 * 
		 * @return int 
		 * 
		 */
		function get lastFPSReading():int;
		/**
		 * returns the integer value of the current frame in this second for the DisplayObject 
		 * being observed.
		 *  
		 * @return int
		 * 
		 */
		function get currentFrame():int;
		/**
		 * retrieves the DisplayObject that is being observed.
		 * 
		 * @return DisplayObject
		 * 
		 */
		function get uiRef():DisplayObject;
		
	}
}