/**
 * Copyright (c) 2009 Symantec
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the 'Software'), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.symantec.premiumServices.asyncThreading.observers {
	import com.symantec.premiumServices.asyncThreading.AsyncThreadingManager;
	
	/**
	 * this attempts to create a queue solution out of the Array class.
	 * 
	 * @author ben rimbey -> ben_rimbey@symantec.com, ben.rimbey@gmail.com 
	 * 
	 */
	public dynamic class FPSReportQueue extends Array {
	    	 
	    /**
	     * overrides the <code>push</code> method on the super <code>Array</code> class. 
	     * 
	     * <p>the length of the queue is controlled by the <code>AsyncThreadingManager</code> 
	 	 * singleton.</p>
	 	 * 
	     * @param args
	     * @return uint 
	     * 
	     */
	    AS3 override function push(...args):uint {
	    	if (this.length >= AsyncThreadingManager.fpsMonitorQueueLength) {
					this.shift();
			}
			 return super.push(args[0]);
	    }
	    
	    /**
	     * calculates an averaged FPS value based on the FPS values that are stored in 
	     * this object.
	     * 
	     * @return int 
	     * 
	     */
	    public function get averageFPS():int {
	    	var total:int = 0;
	    	
	    	for (var i:int = 0; i < this.length; i++) {
	    		total += int(this[i]);
	    	}
	    	
			return Math.round(total / AsyncThreadingManager.fpsMonitorQueueLength);
	    }
	    
	}
}