/**
 * Copyright (c) 2009 Symantec
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the 'Software'), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *  
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *  
 * THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.symantec.premiumServices.asyncThreading.utils {
	import flash.utils.getTimer;
	
	/**
	 * this is a utility class; it is used to track how long a frame takes to render/execute.
	 *  
	 * @author ben rimbey -> ben_rimbey@symantec.com, ben.rimbey@gmail.com 
	 * 
	 */
	public class StopWatch {
		
		/**
		 * the millisecond value in which we started tracking the frame. 
		 */
		protected var startTime:int = 0;
		/**
		 * the millisecond value in which we stopped tracking the frame. 
		 */
		protected var stopTime:int = 0;
		
		/**
		 * invoking this method records the current millisecond value.
		 * 
		 */
		public function start():void {
			startTime = flash.utils.getTimer();
		}
		
		/**
		 * invoking this method records the current millisecond value .
		 * 
		 */
		public function stop():void {
			stopTime = flash.utils.getTimer();
		}
		
		
		/**
		 * this calculates the fps value based on the delta between <code>startTime</code> 
		 * and <code>stopTime</code> values.
		 * 
		 * <p><code>fpsLimit</code> sets the maximum value that can be returned. the default is 
		 * 24, as that is the default framerate for Flex applications.</p>
		 * 
		 * @param fpsLimit
		 * @return int
		 * 
		 */
		public function getCalculatedFPS(fpsLimit:int=24):int {
			var cachedFPSValue:int = Math.round((1 / (stopTime - startTime)) * 1000);
			
			if (cachedFPSValue > fpsLimit) {
				cachedFPSValue = fpsLimit;
			}
			
			return cachedFPSValue;
		}
		
		/**
		 * retrieves the delta between the <code>startTime</code> and <code>stopTime</code> values.
		 * 
		 * @return int 
		 * 
		 */
		public function get lastRunTime():int {
			return stopTime - startTime;
		}
		
	}
}