package net.onthewings.pv3d
{
	
	/**
	 * @Author Ralph Hauwert
	 */
	import com.symantec.premiumServices.asyncThreading.abstract.AbstractAsyncThread;
	
	import flash.utils.Dictionary;
	
	import mx.managers.CursorManager;
	
	import org.papervision3d.core.proto.CameraObject3D;
	import org.papervision3d.core.proto.SceneObject3D;
	import org.papervision3d.core.render.data.RenderSessionData;
	import org.papervision3d.core.render.data.RenderStatistics;
	import org.papervision3d.core.render.material.MaterialManager;
	import org.papervision3d.events.RendererEvent;
	import org.papervision3d.render.BasicRenderEngine;
	import org.papervision3d.view.Viewport3D;
	import org.papervision3d.view.layer.ViewportLayer;
	
	/**
	 * <code>BasicRenderEngine</code> links <code>Viewport3D</code>s, 
	 * <code>Scene3D</code>, and <code>Camera3D</code>s together
	 *  by gathering in all of their data, rendering the data, then calling the 
	 *  necessary functions to update from the rendered data
	 */	
	public class AsyncBasicRenderEngine extends BasicRenderEngine
	{
		public function get showBusyCursor():Boolean {
			return _showBusyCursor;
		}
		
		public function set showBusyCursor(val:Boolean):void {
			var b:Boolean;
			if(val){
				for each (b in threads){
					CursorManager.setBusyCursor();
					break;
				}
			}
			if (_showBusyCursor && !val){
				for each (b in threads){
					CursorManager.removeBusyCursor();
					break;
				}
			}
			_showBusyCursor = val;
		}
		
		protected var _showBusyCursor:Boolean = true;
		
		public function AsyncBasicRenderEngine() {
			super();
		}
		
		override public function renderScene(scene:SceneObject3D, camera:CameraObject3D, viewPort:Viewport3D):RenderStatistics
		{
			// Set the camera's viewport so it can resize its frustum.
			camera.viewport = viewPort.sizeRectangle;
			
			//Update the renderSessionData object.
			renderSessionData.scene = scene;
			renderSessionData.camera = camera;
			renderSessionData.viewPort = viewPort;
			renderSessionData.container = viewPort.containerSprite;
			renderSessionData.triangleCuller = viewPort.triangleCuller;
			renderSessionData.particleCuller = viewPort.particleCuller;
			renderSessionData.renderObjects = scene.objects;
			renderSessionData.renderLayers = null;
			renderSessionData.renderStatistics.clear();
			renderSessionData.clipping = clipping;
			
			if(clipping)
				clipping.reset(renderSessionData);
			
			//Clear the viewport.
			viewPort.updateBeforeRender(renderSessionData);
			
			//Project the Scene (this will fill up the renderlist).
			projectionPipeline.project(renderSessionData);
			if(hasEventListener(RendererEvent.PROJECTION_DONE)){
				dispatchEvent(projectionDoneEvent);
			}
			
			//Render the Scene. TODO: delete null if layers is deleted from doRender
			doRender(renderSessionData, null);

			return renderSessionData.renderStatistics;
		}
		
		/**
		 * Works similarly to <code>renderScene</code>, but also takes an array 
		 * of specific <code>ViewportLayer3D</code>'s to
		 * render
		 * 
		 * @param camera				The <code>CameraObject3D</code> looking at the scene
		 * @param scene					The <code>Scene3D</code> holding the <code>DisplayObject3D</code>'s you want rendered
		 * @param viewPort				The <code>Viewport3D</code> that will display your scene
		 * 
		 * @return RenderStatistics		The <code>RenderStatistics</code> objectholds all the data from the last render
		 * 
		 * @see #renderScene
		 */
		public override function renderLayers(scene:SceneObject3D, camera:CameraObject3D, viewPort:Viewport3D, layers:Array = null):RenderStatistics
		{
			//Update the renderSessionData object.
			renderSessionData.scene = scene;
			renderSessionData.camera = camera;
			renderSessionData.viewPort = viewPort;
			renderSessionData.container = viewPort.containerSprite;
			renderSessionData.triangleCuller = viewPort.triangleCuller;
			renderSessionData.particleCuller = viewPort.particleCuller;
			renderSessionData.renderObjects = getLayerObjects(layers);
			renderSessionData.renderLayers = layers;
			renderSessionData.renderStatistics.clear();
			renderSessionData.clipping = clipping;

			//Clear the viewport.
		
			viewPort.updateBeforeRender(renderSessionData);
			
			//Project the Scene (this will fill up the renderlist).
			projectionPipeline.project(renderSessionData);
			if(hasEventListener(RendererEvent.PROJECTION_DONE)){
				dispatchEvent(projectionDoneEvent);
			}
			
			//Render the Scene.
			doRender(renderSessionData);
			
			return renderSessionData.renderStatistics;
		}
		
		private function getLayerObjects(layers:Array):Array{
			var array:Array = new Array();
			
			for each (var vpl:ViewportLayer in layers){
				array = array.concat(vpl.getLayerObjects());
			}
			return array;
		}
		
		protected override function doRender(renderSessionData:RenderSessionData, layers:Array = null):RenderStatistics
		{
			stopWatch.reset();
			stopWatch.start();
			
			if (_showBusyCursor) CursorManager.setBusyCursor();
			
			//Update Materials.
			MaterialManager.getInstance().updateMaterialsBeforeRender(renderSessionData);

			//Filter the list
			filter.filter(renderList);
			
			//Sort entire list.
			sorter.sort(renderList);
			
			var thread:AbstractAsyncThread = new AsyncBasicRenderEngineDoRenderThread(renderList,renderSessionData,function():void{
				//Update Materials
				MaterialManager.getInstance().updateMaterialsAfterRender(renderSessionData);
				
				renderSessionData.renderStatistics.renderTime = stopWatch.stop();
				renderSessionData.viewPort.updateAfterRender(renderSessionData);
				
				if(hasEventListener(RendererEvent.RENDER_DONE)){
					dispatchEvent(renderDoneEvent);
				}
				
				thread.kill();
				delete threads[thread];
				
				if (_showBusyCursor) CursorManager.removeBusyCursor();
			});
			thread.start();
			threads[thread] = true;
			
			return renderStatistics;
		}
		
		private var threads:Dictionary = new Dictionary(true);

	}
}